@@ -314,7 +314,7 @@ def _find_matches(html, path):
         
         formatted = " ".join(parts).replace("<#", "<")
         formatted = formatted.replace("</#", "</")
-        formatted = formatted.replace("#class=", "class=")
+        formatted = formatted.replace("#id=", "id=")
         formatted = formatted.replace("#class=", "class=")
         matches.append(formatted)
         
@@ -457,7 +457,10 @@ def _parse_to_html(html):
         return html.replace("<#/", "</#")
     if isinstance(html, str):
         html = RE_HTML_NEWLINES1.sub(">", html)
-        return html.replace("<", "<#")
+        html = html.replace("<", "<#")
+        html = html.replace("</", "</#")
+        html = html.replace("id=", "#id=")
+        return html.replace("class=", "#class=")
     raise TypeError("`html` must be in string format.")
 
 
